cytometryContinuous: The continuous cytometry network
Description
Data and network for analyzing the flow cytometry experiment
from Sachs et al. (2005) [1].
This dataset contains the raw measurements from these experiments.
dag An edgeList containing the consensus network (11 nodes, 17 edges).
data A data.frame with 11 variables and 7466 observations.
ivn A list specifying which nodes are under intervention in each observation.
Compatible with the input to sparsebnData.
Details
The dataset consists of n = 7466 observations of p = 11 continuous
variables corresponding to different proteins and phospholipids in human
immune system cells, and each observation indicates the measured level of
each biomolecule in a single cell under different experimental interventions.
Based on this data, a consensus network was reconstructed and validated, which
is included as well.
# NOT RUN {# Create a valid sparsebnData object from the cytometry datadata(cytometryContinuous)
dat <- sparsebnData(cytometryContinuous$data, type = "c", ivn = cytometryContinuous$ivn)
# }