Learn R Programming

sparsebn (version 0.1.2)

cytometryDiscrete: The discrete cytometry network

Description

Data and network for analyzing the flow cytometry experiment from Sachs et al. (2005) [1]. The data is a cleaned and discretized version of the raw data (see cytometryContinuous for details) from these experiments.

Usage

data(cytometryDiscrete)

Arguments

Format

A list with three components:

  • dag An edgeList containing the consensus network (11 nodes, 17 edges).

  • data A data.frame with 11 variables and 5400 observations.

  • ivn A list specifying which nodes are under intervention in each observation. Compatible with the input to sparsebnData.

Details

After cleaning and pre-processing, the raw continuous measurements have been binned into one of three levels: low = 0, medium = 1, or high = 2. Due to the pre-processing, the discrete data contains fewer observations (n = 5400) compared to the raw, continuous data.

References

[1] Sachs, Karen, et al. "Causal protein-signaling networks derived from multiparameter single-cell data." Science 308.5721 (2005): 523-529.

Examples

Run this code
# NOT RUN {
# Create a valid sparsebnData object from the cytometry data
data(cytometryDiscrete)
dat <- sparsebnData(cytometryDiscrete$data, type = "d", ivn = cytometryDiscrete$ivn)

# }

Run the code above in your browser using DataLab