Learn R Programming

sparsebn (version 0.1.2)

plotDAG: Plot a DAG

Description

Using some sensible defaults for large graphs, plot a DAG object. Uses igraph package by default.

Usage

plotDAG(x, ...)

Arguments

...

Additional arguments to plot.

Details

This method is not intended for customization. For more control over the output, use plot and see setPlotPackage for plotting only and/or setGraphPackage for even more control. These methods grants the user the full feature set of the selected package.