Data and network for analyzing the flow cytometry experiment
from Sachs et al. (2005) [1].
The data is a cleaned and discretized version of the raw data (see
cytometryContinuous for details) from these experiments.
dag An edgeList containing the consensus network (11 nodes, 17 edges).
data A data.frame with 11 variables and 5400 observations.
ivn A list specifying which nodes are under intervention in each observation.
Compatible with the input to sparsebnData.
Details
After cleaning and pre-processing, the raw continuous measurements have been
binned into one of three levels: low = 0, medium = 1, or high = 2. Due to the
pre-processing, the discrete data contains fewer observations (n = 5400)
compared to the raw, continuous data.
# NOT RUN {# Create a valid sparsebnData object from the cytometry datadata(cytometryDiscrete)
dat <- sparsebnData(cytometryDiscrete$data, type = "d", ivn = cytometryDiscrete$ivn)
# }